@@ -1,8 +1,9 @@
 import numpy as np
 import random as rd
-from imblearn.over_sampling import SMOTE 
+# from imblearn.over_sampling import SMOTE 
 
 # following libraries for classification test
+# import test_nn
 from . import test_nn
 
 import statistics 
@@ -34,12 +35,19 @@ class DataAugment:
 		Data_a: complete data with augmented datapoints
 		Ext_d: Only the augmented data points
 		Ext_not: The data that was created but ignored
+
+		dist_percent: decides the threshold value for 
+		permissible distance in order to use a point 
+		for generating augmented values
+
 		'''
 
 		# extract parameters
 		# set default first
 		randmx=1
 		blind=False
+		verbose=False
+		dist_percent=0.6
 		
 
 		if 'data' in params.keys():
@@ -54,9 +62,14 @@ class DataAugment:
 			randmx=params['randmx']
 		if 'blind' in params.keys():
 			blind=params['blind']			
+		if 'verbose' in params.keys():
+			verbose=params['verbose']						
+		if 'dist_percent' in params.keys():
+			dist_percent=params['dist_percent']									
+
 
 		
-
+		
 
 		# print("to check if data is correct type")
 		
@@ -87,6 +100,32 @@ class DataAugment:
 		# print("y shape\n",y.shape,"\n*****")
 		# y is the dataset for majority class
 
+		# calculate k neighbors for each point
+		# d_k
+		# sort them 
+		# threshold is distance from 80th point
+
+
+		# for each point we will have a list of distances
+		# calculate distance of each point from
+		# every other point
+		dist_matrix=np.linalg.norm(x - x[:,None], axis=-1)
+		# print("The distance matrix is \n",dist_matrix)
+		dist_matrix.sort(axis=1)
+		# print("the distance matrix, sorted is \n",dist_matrix)
+		kth_distances=dist_matrix[:, (k-1)]
+		# print("The kth neighbor distance array is \n",kth_distances)
+		kth_distances_sorted=np.sort(kth_distances)
+		# print("The old kth neighbor distance array is \n",kth_distances)
+		# print("The sorted kth neighbor distance array is \n",kth_distances_sorted)
+		threshold_dist=kth_distances_sorted[math.floor(dist_percent*len(kth_distances_sorted))]
+		# print("The threshold distance is ",threshold_dist)
+
+		# plt.plot([i for i in range(len(kth_distances))], kth_distances)
+		# plt.show()
+		
+
+
 		Data=np.concatenate((x,y))
 		# print("Data inside\n", Data,"\n*****")
 		# data is just all features with minority class on top
@@ -106,6 +145,9 @@ class DataAugment:
 		psOUT=[]
 		# print("N = ",N)
 		Q=N//len(x)+1
+		
+		# len(x0) after removing the 20%
+
 		# +1 will handle 0 cases
 		# print("value of Q is ",Q)
 		# print("length of x is ",len(x))
@@ -129,7 +171,19 @@ class DataAugment:
 			# print("Next loop runs ",len(x)," times")
 			# this loops runs for all the features
 			# in the minority set
+
+
 			for i in range(len(x)):
+
+				# if the distance of x_i
+				# is less than the threshold
+				if kth_distances[i]>threshold_dist:
+					# print("More than threshold, skipping ",x[i])
+					continue
+
+
+
+
 				# print("i=",i)
 
 				if N==0:
@@ -173,6 +227,8 @@ class DataAugment:
 						
 						m1 = m0 + alphak * (kv[j,:] - m0)
 						m0 = m1
+						
+
 					# print("m1 = ",m1)
 					# above for loop is what sets the code apart
 					# loop runs for the number of neighbors
@@ -216,8 +272,9 @@ class DataAugment:
 
 					if can_use:
 					# if posit[0]<=len(x) or (randmx<10**(-4)):					
-						if N%500==0:
-							print(N)
+						if verbose:
+							if N%5000==0:
+								print(N)
 						m1=m1.reshape(1,len(Data[0]))
 						#print("m1  Ext_d shape",m1,m1.shape,Ext_d.shape)
 						Ext_d = np.concatenate((Ext_d, m1))
@@ -292,7 +349,7 @@ def main():
 	print("KNNOR Data:")
 	print(Data_a)
 	print("************************************")
-	try_SMOTE(l,N,k)
+	# try_SMOTE(l,N,k)
 
 
 def try_SMOTE(l,N,k):
